/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.field.shape;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.field.shape.preview.ShapePropertyMappingPanel;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@NbBundle.Messages("ShapeMappingPanel property box=Property mapping")
public class ShapeMappingPanel extends javax.swing.JPanel {


    public static final String PROP_CONTENT_TYPE ="contentType";
    
    /**
     * Creates new form ShapeMappingPanel
     */
    public ShapeMappingPanel() {
        initComponents();
        contentFieldsButton.addChangeListener(new ChangeListener() {

            @Override
            public void stateChanged(ChangeEvent e) {
                firePropertyChange(PROP_CONTENT_TYPE, -1, getContentType());
            }
        });
        contentTreatmentZonesButton.addChangeListener(new ChangeListener() {

            @Override
            public void stateChanged(ChangeEvent e) {
                firePropertyChange(PROP_CONTENT_TYPE, -1, getContentType());
            }
        });        
    }

    public ShapePropertyMappingPanel getShapePropertyMappingPanel() {
        return shapePropertyMappingPanel;
    }

    /**
     * Retrieve the content type setting for this shape file.
     *
     * <p> possible values: <ul> <li>{@link ShapeMappingPanel#CONTENT_NONE}</li>
     * <li>{@link ShapeMappingPanel#CONTENT_FIELDS}</li>
     * <li>{@link ShapeMappingPanel#CONTENT_TREATMENT_ZONES}</li> </ul> </p>
     *
     * @return
     */
    public int getContentType() {
        int contentType = ShapeDataObject.CONTENT_NONE;
        if (contentFieldsButton.isSelected()) {
            contentType = ShapeDataObject.CONTENT_FIELDS;
        }
        if (contentTreatmentZonesButton.isSelected()) {
            contentType = ShapeDataObject.CONTENT_TREATMENT_ZONES;
        }
        return contentType;
    }

    /**
     * Set the selected content type for this panel
     * 
     * <p> possible values: <ul> <li>{@link ShapeMappingPanel#CONTENT_NONE}</li>
     * <li>{@link ShapeMappingPanel#CONTENT_FIELDS}</li>
     * <li>{@link ShapeMappingPanel#CONTENT_TREATMENT_ZONES}</li> </ul> </p>
     * 
     * @param type 
     */
    public void setContentType(int type) {
        switch (type) {
            case ShapeDataObject.CONTENT_FIELDS:
                contentFieldsButton.setSelected(true);
                break;
            case ShapeDataObject.CONTENT_TREATMENT_ZONES:
                contentTreatmentZonesButton.setSelected(true);
                break;
        }
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        contentButtonGroup = new javax.swing.ButtonGroup();
        shapePropertyMappingPanel = new nl.cloudfarming.client.field.shape.preview.ShapePropertyMappingPanel();
        jPanel1 = new javax.swing.JPanel();
        contentFieldsButton = new javax.swing.JRadioButton();
        contentTreatmentZonesButton = new javax.swing.JRadioButton();

        shapePropertyMappingPanel.setBorder(javax.swing.BorderFactory.createTitledBorder(null, org.openide.util.NbBundle.getMessage(ShapeMappingPanel.class, "ShapeMappingPanel.shapePropertyMappingPanel.border.title"), javax.swing.border.TitledBorder.DEFAULT_JUSTIFICATION, javax.swing.border.TitledBorder.DEFAULT_POSITION, null, java.awt.Color.black)); // NOI18N

        jPanel1.setBackground(new java.awt.Color(255, 255, 255));
        jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder(org.openide.util.NbBundle.getMessage(ShapeMappingPanel.class, "ShapeMappingPanel.jPanel1.border.title"))); // NOI18N

        contentFieldsButton.setBackground(new java.awt.Color(255, 255, 255));
        contentButtonGroup.add(contentFieldsButton);
        org.openide.awt.Mnemonics.setLocalizedText(contentFieldsButton, org.openide.util.NbBundle.getMessage(ShapeMappingPanel.class, "ShapeMappingPanel.contentFieldsButton.text")); // NOI18N
        contentFieldsButton.setName("contentFieldsButton"); // NOI18N
        contentFieldsButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                contentFieldsButtonActionPerformed(evt);
            }
        });

        contentTreatmentZonesButton.setBackground(new java.awt.Color(255, 255, 255));
        contentButtonGroup.add(contentTreatmentZonesButton);
        org.openide.awt.Mnemonics.setLocalizedText(contentTreatmentZonesButton, org.openide.util.NbBundle.getMessage(ShapeMappingPanel.class, "ShapeMappingPanel.contentTreatmentZonesButton.text")); // NOI18N
        contentTreatmentZonesButton.setName("contentTreatmentZonesButton"); // NOI18N
        contentTreatmentZonesButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                contentTreatmentZonesButtonActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(contentFieldsButton, javax.swing.GroupLayout.PREFERRED_SIZE, 251, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(contentTreatmentZonesButton, javax.swing.GroupLayout.PREFERRED_SIZE, 251, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(0, 83, Short.MAX_VALUE))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addComponent(contentFieldsButton)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(contentTreatmentZonesButton)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(shapePropertyMappingPanel, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(shapePropertyMappingPanel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(18, 18, 18)
                .addComponent(jPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents

    private void contentFieldsButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_contentFieldsButtonActionPerformed
        // TODO add your handling code here:
    }//GEN-LAST:event_contentFieldsButtonActionPerformed

    private void contentTreatmentZonesButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_contentTreatmentZonesButtonActionPerformed
        // TODO add your handling code here:
    }//GEN-LAST:event_contentTreatmentZonesButtonActionPerformed
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.ButtonGroup contentButtonGroup;
    private javax.swing.JRadioButton contentFieldsButton;
    private javax.swing.JRadioButton contentTreatmentZonesButton;
    private javax.swing.JPanel jPanel1;
    private nl.cloudfarming.client.field.shape.preview.ShapePropertyMappingPanel shapePropertyMappingPanel;
    // End of variables declaration//GEN-END:variables
}
