/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.field.shape;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;
import javax.swing.JComponent;
import nl.cloudfarming.client.field.model.Shape;
import org.openide.DialogDisplayer;
import org.openide.WizardDescriptor;
import org.openide.util.NbBundle;

/**
 * 
 * @author johan
 */
// An example action demonstrating how the wizard could be called from within
// your code. You can move the code below wherever you need, or register an action:
// @ActionID(category="...", id="nl.cloudfarming.client.field.shape.ShapePropertyMappingWizardAction")
// @ActionRegistration(displayName="Open ShapePropertyMapping Wizard")
// @ActionReference(path="Menu/Tools", position=...)
@NbBundle.Messages("ShapePropertyMappingWizardAction dialog title=Configure shape property mapping")
public final class ShapePropertyMappingWizardAction implements ActionListener {
    
    private final ShapeDataObject shapeDataObject;
    private ShapePropertyMapping mapping;

    public ShapePropertyMappingWizardAction(ShapeDataObject shapeDataObject) {
        this.shapeDataObject = shapeDataObject;
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new ArrayList<>();
        panels.add(new ShapePropertyMappingWizardPanel1());
        String[] steps = new String[panels.size()];
        for (int i = 0; i < panels.size(); i++) {
            Component c = panels.get(i).getComponent();
            // Default step name to component name of panel.
            steps[i] = c.getName();
            if (c instanceof JComponent) { // assume Swing components
                JComponent jc = (JComponent) c;
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_SELECTED_INDEX, i);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DATA, steps);
                jc.putClientProperty(WizardDescriptor.PROP_AUTO_WIZARD_STYLE, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DISPLAYED, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_NUMBERED, true);
            }
        }
        WizardDescriptor wiz = new WizardDescriptor(new WizardDescriptor.ArrayIterator<>(panels));
        // {0} will be replaced by WizardDesriptor.Panel.getComponent().getName()
        wiz.setTitleFormat(new MessageFormat("{0}"));
        wiz.setTitle(Bundle.ShapePropertyMappingWizardAction_dialog_title());
        wiz.putProperty(ShapePropertyMappingWizardPanel1.PROP_DATA_OBJECT, shapeDataObject);

        if (DialogDisplayer.getDefault().notify(wiz) == WizardDescriptor.FINISH_OPTION) {
            
            String nameProperty = (String) wiz.getProperty(ShapePropertyMappingWizardPanel1.PROP_NAME_PROPERTY);
            String valueProperty = (String) wiz.getProperty(ShapePropertyMappingWizardPanel1.PROP_VALUE_PROPERTY);
            Boolean saveToRegistry = (Boolean) wiz.getProperty(ShapePropertyMappingWizardPanel1.PROP_SAVE_TO_REGISTRY);
            
            shapeDataObject.setNameProperty(nameProperty);
            shapeDataObject.setValueProperty(valueProperty);
            shapeDataObject.setContentType(ShapeDataObject.CONTENT_TREATMENT_ZONES);

            for (Shape shape : shapeDataObject.getShapes()){
                shape.setNameFromAttribute(nameProperty);
                shape.setValueFromAttribute(valueProperty);
            }
            
            mapping = new ShapePropertyMapping(nameProperty, valueProperty);
            
            if (saveToRegistry) {
                ShapePropertyMappingRegistry.getInstance().add(mapping);
            }
        }
        
    }

    public ShapePropertyMapping getMapping() {
        return mapping;
    }
}
