/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.shape.preview;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle;

/**
 * Allows the user to select the property from a shape file which represents the
 * 'Name' of a shape
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages({
    "Shape property mapping panel name label=Name: ",
    "Shape property mapping panel name value=Value: ",
    "Shape property mapping panel no properties message= None found"
})
public class ShapePropertyMappingPanel extends JPanel {

    public static final String PROP_COMBOBOX_MAPPING_NAME = "nameMappingBox";
    public static final String PROP_COMBOBOX_MAPPING_VALUE = "valueMappingBox";
    private DefaultComboBoxModel namePropertiesModel = new DefaultComboBoxModel();
    private DefaultComboBoxModel valuePropertiesModel = new DefaultComboBoxModel();
    private JComboBox namePropertyBox;
    private JComboBox valuePropertyBox;

    public ShapePropertyMappingPanel() {
        this.setLayout(new MigLayout("wrap 2, insets 0 8 0 0"));
        this.setBackground(Color.white);

        namePropertyBox = new JComboBox(namePropertiesModel);
        namePropertyBox.setName(PROP_COMBOBOX_MAPPING_NAME);
        namePropertyBox.setBackground(Color.WHITE);
        
        valuePropertyBox = new JComboBox(valuePropertiesModel);
        valuePropertyBox.setName(PROP_COMBOBOX_MAPPING_VALUE);
        valuePropertyBox.setBackground(Color.WHITE);
        
        this.add(new JLabel(Bundle.Shape_property_mapping_panel_name_label()));
        this.add(namePropertyBox);
        this.add(new JLabel(Bundle.Shape_property_mapping_panel_name_value()));
        this.add(valuePropertyBox);
        
        namePropertyBox.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                firePropertyChange(PROP_COMBOBOX_MAPPING_NAME, null, namePropertyBox.getSelectedItem());
            }
        });
        
        valuePropertyBox.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                firePropertyChange(PROP_COMBOBOX_MAPPING_VALUE, null, valuePropertyBox.getSelectedItem());
            }
        });        

    }

    /**
     * Set available shape properties
     *
     * @param properties
     */
    public  void setAvailableNameProperties(List<String> properties) {
        namePropertiesModel.removeAllElements();
        namePropertyBox.removeAllItems();
        if (properties == null || properties.isEmpty()) {
            namePropertiesModel.addElement(Bundle.Shape_property_mapping_panel_no_properties_message());
            namePropertyBox.setEnabled(false);

        } else {
            namePropertyBox.setEnabled(true);
            for (String property : properties) {
                namePropertiesModel.addElement(property);
            }
            if (namePropertiesModel.getIndexOf("") >= 0) {
                namePropertiesModel.setSelectedItem("");
            }
        }
    }
    
    /**
     * Set available shape properties
     *
     * @param properties
     */
    public  void setAvailableValueProperties(List<String> properties) {
        valuePropertiesModel.removeAllElements();
        valuePropertyBox.removeAllItems();
        if (properties == null || properties.isEmpty()) {
            
            valuePropertiesModel.addElement(Bundle.Shape_property_mapping_panel_no_properties_message());
            valuePropertyBox.setEnabled(false);
        } else {
            namePropertyBox.setEnabled(true);
            valuePropertyBox.setEnabled(true);
            for (String property : properties) {
                valuePropertiesModel.addElement(property);
            }
            if (valuePropertiesModel.getIndexOf("") >= 0) {
                valuePropertiesModel.setSelectedItem("");
            }
        }
    }

    public void setSelectedNameProperty(String property){
        namePropertiesModel.setSelectedItem(property);
    }
    
    public void setSelectedValueProperty(String property){
        valuePropertiesModel.setSelectedItem(property);
    }
    


}
