/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.shape.preview;

import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.GeometryCollection;
import java.awt.BorderLayout;
import java.awt.Color;
import java.util.ArrayList;
import java.util.List;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import nl.cloudfarming.client.field.model.Shape;
import nl.cloudfarming.client.field.model.ShapeWidget;
import nl.cloudfarming.client.geoviewer.render.GeometricalWidget;
import nl.cloudfarming.client.geoviewer.render.SimpleGeoTranslator;
import nl.cloudfarming.client.field.shape.ShapeDataObject;
import org.netbeans.api.visual.model.ObjectScene;
import org.netbeans.api.visual.widget.LayerWidget;

/**
 * Panel which displays all the shapes within the provided ShapeDataObject
 *
 * @author Merijn Zengers
 */
public class ShapesPanel extends JPanel {

    private final JPanel contentPanel = new JPanel(new BorderLayout());
    private final JScrollPane jScrollPane;

    public ShapesPanel(ShapeDataObject shapeFile, ObjectScene scene, PreviewPanelPalette palette) {
        this.setLayout(new BorderLayout());
        
        this.setBackground(Color.white);

        jScrollPane = new javax.swing.JScrollPane();
        jScrollPane.setViewportView(contentPanel);
        this.add(jScrollPane);


        List<Geometry> geometries = new ArrayList();
        for (Shape shape : shapeFile.getShapes()) {
            geometries.add(shape.getGeometry());
        }

        LayerWidget mainLayer = new LayerWidget(scene);
        scene.setOpaque(false);
        scene.addChild(mainLayer);

        if (geometries.size() > 0) {
            Geometry[] g = geometries.toArray(new Geometry[geometries.size()]);
            GeometryCollection geoCollection = new GeometryCollection(g, g[0].getFactory());

            for (Shape shape : shapeFile.getShapes()) {
                GeometricalWidget widget = new ShapeWidget(scene, new SimpleGeoTranslator(), shape, palette, geoCollection.getEnvelope());

                widget.getActions().addAction(scene.createSelectAction());
                widget.getActions().addAction(scene.createObjectHoverAction());

                mainLayer.addChild(widget);
                scene.addObject(shape, widget);
            }
        }

        contentPanel.add(scene.createView());
    }
}
